@@ -73,6 +73,7 @@ sub access {
     trace( 2, $repo, $user, $aa, $ref );
     _die "invalid user '$user'" if not( $user and $user =~ $USERNAME_PATT );
     sanity($repo);
+    return "$aa any $repo $user DENIED by fallthru" unless update_hook_present($repo);
 
     my @rules;
     my $deny_rules;
@@ -395,9 +396,12 @@ sub memberships {
 
     push @ret, @{ $groups{$base} } if exists $groups{$base};
     push @ret, @{ $groups{$base2} } if $base2 and exists $groups{$base2};
-    for my $i ( keys %{ $patterns{groups} } ) {
-        if ( $base =~ /^$i$/ or $base2 and ( $base2 =~ /^$i$/ ) ) {
-            push @ret, @{ $groups{$i} };
+    if ($type eq 'repo') {
+        # regexes can only be used for repos, not for users
+        for my $i ( keys %{ $patterns{groups} } ) {
+            if ( $base =~ /^$i$/ or $base2 and ( $base2 =~ /^$i$/ ) ) {
+                push @ret, @{ $groups{$i} };
+            }
         }
     }
 
@@ -658,7 +662,7 @@ Usage:  gitolite list-members <group name>
 in your rc file[1], gitolite cannot expand group names completely; only your
 external database can.
 
-[1]: http://gitolite.com/gitolite/conf.html#ldap
+[1]: http://gitolite.com/gitolite/conf.html#getting-user-group-info-from-ldap
 
 =cut
 
